@@ -1,7 +1,6 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 /* exported SessionMode, listModes */
 
-const ByteArray = imports.byteArray;
 const GLib = imports.gi.GLib;
 const Signals = imports.signals;
 
@@ -19,6 +18,7 @@ const _modes = {
         themeResourceName: 'gnome-shell-theme.gresource',
         hasOverview: false,
         showCalendarEvents: false,
+        showWelcomeDialog: false,
         allowSettings: false,
         allowExtensions: false,
         allowScreencast: false,
@@ -46,7 +46,9 @@ const _modes = {
         isGreeter: true,
         isPrimary: true,
         unlockDialog: imports.gdm.loginDialog.LoginDialog,
-        components: ['polkitAgent'],
+        components: Config.HAVE_NETWORKMANAGER
+            ? ['networkAgent', 'polkitAgent']
+            : ['polkitAgent'],
         panel: {
             left: [],
             center: ['dateMenu'],
@@ -70,6 +72,7 @@ const _modes = {
     'user': {
         hasOverview: true,
         showCalendarEvents: true,
+        showWelcomeDialog: true,
         allowSettings: true,
         allowExtensions: true,
         allowScreencast: true,
@@ -106,8 +109,8 @@ function _loadMode(file, info) {
     let fileContent, success_, newMode;
     try {
         [success_, fileContent] = file.load_contents(null);
-        fileContent = ByteArray.toString(fileContent);
-        newMode = JSON.parse(fileContent);
+        const decoder = new TextDecoder();
+        newMode = JSON.parse(decoder.decode(fileContent));
     } catch (e) {
         return;
     }
